@@ -1,38 +1,28 @@
 package Net::Google::Spreadsheets::Worksheet;
-use Moose;
+use Any::Moose;
+use namespace::autoclean;
+use Net::Google::DataAPI;
+
+with 'Net::Google::DataAPI::Role::Entry';
+
 use Carp;
-use namespace::clean -except => 'meta';
-
-with 'Net::Google::Spreadsheets::Role::Base';
-
 use Net::Google::Spreadsheets::Cell;
 use XML::Atom::Util qw(first);
 
-has row_feed => (
-    traits => ['Net::Google::Spreadsheets::Traits::Feed'],
-    is => 'ro',
-    isa => 'Str',
+feedurl row => (
     entry_class => 'Net::Google::Spreadsheets::Row',
-    entry_arg_builder => sub {
+    as_content_src => 1,
+    arg_builder => sub {
         my ($self, $args) = @_;
         return {content => $args};
     },
-    from_atom => sub {
-        my $self = shift;
-        $self->{row_feed} = $self->atom->content->elem->getAttribute('src');
-    },
 );
 
-has cellsfeed => (
-    traits => ['Net::Google::Spreadsheets::Traits::Feed'],
-    is => 'ro',
-    isa => 'Str',
+feedurl cell => (
     entry_class => 'Net::Google::Spreadsheets::Cell',
-    entry_arg_builder => sub {
-        my ($self, $args) = @_;
-        croak 'you can\'t call add_cell!';
-    },
-    query_arg_builder => sub {
+    can_add => 0,
+    rel => 'http://schemas.google.com/spreadsheets/2006#cellsfeed',
+    query_builder => sub {
         my ($self, $args) = @_;
         if (my $col = delete $args->{col}) {
             $args->{'max-col'} = $col;
@@ -46,56 +36,44 @@ has cellsfeed => (
         }
         return $args;
     },
-    from_atom => sub {
-        my ($self) = @_;
-        ($self->{cellsfeed}) = map {$_->href} grep {
-            $_->rel eq 'http://schemas.google.com/spreadsheets/2006#cellsfeed'
-        } $self->atom->link;
-    }
+
 );
 
-has row_count => (
+entry_has row_count => (
     isa => 'Int',
     is => 'rw',
     default => 100,
-    trigger => sub {$_[0]->update}
+    tagname => 'rowCount',
+    ns => 'gs',
 );
 
-has col_count => (
+entry_has col_count => (
     isa => 'Int',
     is => 'rw',
     default => 20,
-    trigger => sub {$_[0]->update}
+    tagname => 'colCount',
+    ns => 'gs',
 );
 
-around to_atom => sub {
-    my ($next, $self) = @_;
-    my $entry = $next->($self);
-    $entry->set($self->gsns, 'rowCount', $self->row_count);
-    $entry->set($self->gsns, 'colCount', $self->col_count);
-    return $entry;
-};
-
-after from_atom => sub {
-    my ($self) = @_;
-    $self->{row_count} = $self->atom->get($self->gsns, 'rowCount');
-    $self->{col_count} = $self->atom->get($self->gsns, 'colCount');
-};
-
 __PACKAGE__->meta->make_immutable;
 
 sub batchupdate_cell {
     my ($self, @args) = @_;
     my $feed = XML::Atom::Feed->new;
     for ( @args ) {
-        my $id = sprintf("%s/R%sC%s",$self->cellsfeed, $_->{row}, $_->{col});
+        my $id = sprintf("%s/R%sC%s",$self->cell_feedurl, $_->{row}, $_->{col});
         $_->{id} = $_->{editurl} = $id;
+        $_->{container} = $self,
         my $entry = Net::Google::Spreadsheets::Cell->new($_)->to_atom;
-        $entry->set($self->batchns, operation => '', {type => 'update'});
-        $entry->set($self->batchns, id => $id);
+        $entry->set($self->ns('batch'), operation => '', {type => 'update'});
+        $entry->set($self->ns('batch'), id => $id);
         $feed->add_entry($entry);
     }
-    my $res_feed = $self->service->post($self->cellsfeed."/batch", $feed, {'If-Match' => '*'});
+    my $res_feed = $self->service->post(
+        $self->cell_feedurl."/batch", 
+        $feed, 
+        {'If-Match' => '*'}
+    );
     $self->sync;
     return map {
         Net::Google::Spreadsheets::Cell->new(
@@ -104,7 +82,7 @@ sub batchupdate_cell {
         )
     } grep {
         my $node = first(
-            $_->elem, $self->batchns->{uri}, 'status'
+            $_->elem, $self->ns('batch')->{uri}, 'status'
         );
         $node->getAttribute('code') == 200;
     } $res_feed->entries;
